@@ -484,7 +484,8 @@ def get_plugins_loader(plugin_group):
     plugins_paths.insert(0, plugins_fallback_path)
 
     # add some extra paths from site-packages directories
-    for path in site.getsitepackages():
+    sitepackages = site.getsitepackages() + [site.getusersitepackages()]
+    for path in sitepackages:
       plugins_paths.insert(0, str(Path.joinpath(Path(path), 'parscival_plugins')))
 
     # append the plugin type to each of paths
